@@ -45,7 +45,7 @@ def assert_aws_credentials():
 	assert 'AWS_SECRET_ACCESS_KEY' in os.environ, "Missing environment variable AWS_SECRET_ACCESS_KEY"
 
 def prepare_docker():
-	prepare_docker_image(f"{IMAGE_NAME}:{IMAGE_TAG}", IMAGE_NAME, IMAGE_TAG)
+	return prepare_docker_image(f"{IMAGE_NAME}:{IMAGE_TAG}", IMAGE_NAME, IMAGE_TAG)
 
 def prepare_docker_image(image, name, tag):
 	import docker
@@ -54,7 +54,7 @@ def prepare_docker_image(image, name, tag):
 	if len(images):
 		image = images[0]
 	else:
-		print(f'Unable to find {image}:{tag} in local storage. Pulling the image...')
+		print(f'Unable to find {image} in local storage. Pulling the image...')
 		image = client.images.pull(name, tag)
 	return client
 
@@ -117,7 +117,8 @@ class DojoCLI(click.MultiCommand):
 				ssh_connection_timeout,
 				ssh_connection_attempts):			
 		"""Initialize a training dojo in a specified infrastructure provider."""
-		assert provider == 'aws	' or provider == 'local', f"Provider {provider} is not publicly available in version {VERSION}"
+		provider = provider.strip().lower() if provider is not None and str == type(provider) and len(provider) > 0 else None
+		assert provider == 'aws' or provider == 'local', f"Provider {provider} is not publicly available in version {VERSION}"
 		assert backend == 'docker', f"Backend {backend} is not publicly available in version {VERSION}"
 
 		#check for the aws settings
@@ -232,6 +233,9 @@ class DojoCLI(click.MultiCommand):
 
 	@click.command()
 	def prune():
+		"""Remove deactivated dojo instances.
+		
+		Finds all dojo instances with the state equal to inactive and force deletes them."""
 		client = prepare_docker()
 		container = client.containers.run(	
 			image = IMAGE, 
@@ -371,6 +375,8 @@ class JobCLI(click.MultiCommand):
 		"""Return key value settings for the specified job."""
 		
 		client = prepare_docker()
+
+		backend, provider = get_backend_provider(job = job)
 		
 		container = client.containers.run(	
 			image=IMAGE, 
@@ -398,7 +404,7 @@ class JobCLI(click.MultiCommand):
 		client = prepare_docker()
 		print('done')
 
-		backend, provider = get_backend_provider(job = job)		
+		backend, provider = get_backend_provider(job = job)
 
 		env = dict({ "KAEN_JOB": job,
 					 "KAEN_JOB_REPLICAS": replicas,
